Structs
- Build
Behavior - Build
Behavior Builder - Use builder syntax to set the inputs and finish with
build(). - Build
Building Behavior - Build
Building Behavior Builder - Use builder syntax to set the inputs and finish with
build(). - Build
Step
build().build().