Module plunder

Module plunder 

Structs

PlunderBehavior
PlunderBehaviorBuilder
Use builder syntax to set the inputs and finish with build().
PlunderTargetBehavior
PlunderTargetBehaviorBuilder
Use builder syntax to set the inputs and finish with build().