Structs
- BuyResources
Behavior - BuyResources
Behavior Builder - Use builder syntax to set the inputs and finish with
build(). - Sell
Resources Behavior - Sell
Resources Behavior Builder - Use builder syntax to set the inputs and finish with
build(). - Trade
Behavior - Trade
Behavior Builder - Use builder syntax to set the inputs and finish with
build().