Module city

Module city 

Modules

stability

Structs

City
CityBuilder
Use builder syntax to set the inputs and finish with build().
CityName
CitySearch
CitySearchBuilder
Use builder syntax to set the inputs and finish with build().
PublicCity
Public data about a city, to which any player can have access.