pub struct City { /* private fields */ }Implementations
Sourceimpl City
impl City
pub fn coord(&self) -> Coord
pub fn name(&self) -> &CityName
pub fn owner(&self) -> &Ruler
pub fn infrastructure(&self) -> &Infrastructure
pub fn infrastructure_mut(&mut self) -> &mut Infrastructure
pub fn stability(&self) -> Stability
pub fn player(&self) -> Option<PlayerId>
Sourcepub fn is_owned_by_player(&self) -> bool
pub fn is_owned_by_player(&self) -> bool
Checks whether the city belongs to a player.
pub fn is_owned_by_player_and<F>(&self, f: F) -> bool
Sourcepub fn is_owned_by_bot(&self) -> bool
pub fn is_owned_by_bot(&self) -> bool
Checks whether the city belongs to a bot.
pub fn is_owned_by_bot_and<F>(&self, f: F) -> bool
Sourcepub fn is_owned_by_precursor(&self) -> bool
pub fn is_owned_by_precursor(&self) -> bool
Checks whether the city belongs to a precursor.
pub fn is_owned_by_precursor_and<F>(&self, f: F) -> bool
pub fn score(&self, stats: &InfrastructureStats) -> Result<Score>
Sourcepub fn round_production(&self, stats: &InfrastructureStats) -> Result<Resources>
pub fn round_production(&self, stats: &InfrastructureStats) -> Result<Resources>
Determines the amount of resources generated by the city’s mines while applying all relevant modifiers, such as city stability.
Sourcepub fn maintenance(&self, stats: &InfrastructureStats) -> Result<Maintenance>
pub fn maintenance(&self, stats: &InfrastructureStats) -> Result<Maintenance>
Determines the maintenance tax required for the city buildings.
pub fn storage_capacity( &self, stats: &InfrastructureStats, ) -> Result<OverallStorageCapacity>