Event

Enum Event 

pub enum Event {
    ChatMessage {
        id: EventId,
        world: WorldId,
        message: ChatMessage,
    },
    City {
        id: EventId,
        world: WorldId,
        coord: Coord,
    },
    Drop {
        id: EventId,
        world: WorldId,
    },
    Market {
        id: EventId,
        world: WorldId,
    },
    Military {
        id: EventId,
        world: WorldId,
        player: PlayerId,
    },
    Player {
        id: EventId,
        world: WorldId,
        player: PlayerId,
    },
    PublicCity {
        id: EventId,
        world: WorldId,
        coord: Coord,
    },
    Report {
        id: EventId,
        world: WorldId,
        report: Box<ReportKind>,
    },
    Round {
        id: EventId,
        world: WorldId,
        round: Round,
    },
}

Variants



ChatMessage

Uma nova mensagem foi enviada no chat.

Fields

world: WorldId
message: ChatMessage


City

Indica que houve uma alteração nos dados da cidade, públicos ou privados.

Este evento é emitido apenas para o dono da cidade. Se você acredita que todos os jogadores devem ser notificados, considere usar Event::PublicCity.

Fields

world: WorldId
coord: Coord


Drop

Sinaliza que todos os jogadores ativos devem se desconectar, pois o mundo está prestes a ser descartado.

Este evento DEVE ser emitido apenas dentro da implementação de Drop da struct World.

Fields

world: WorldId


Market

Indica que os preços do mercado mudaram.

Fields

world: WorldId


Military

Indica que houve uma alteração nas forças militares do jogador. Geralmente significa que novas manobras foram iniciadas, pois os exércitos em si são processados no final da rodada.

Fields

world: WorldId
player: PlayerId


Player

Indica que houve uma alteração em alguns dados do jogador, públicos ou privados.

Fields

world: WorldId
player: PlayerId


PublicCity

Indica que houve uma alteração nos dados públicos da cidade.

Diferentemente de Event::City, que é emitido apenas para o dono da cidade, este evento é enviado para todos os jogadores do mundo.

Como regra, sempre que a situação exigir a emissão deste evento, Event::City também deve ser emitido, mas o contrário não é verdadeiro!

Fields

world: WorldId
coord: Coord


Report

Um relatório foi gerado.

Fields

world: WorldId
report: Box<ReportKind>


Round

Indica alterações na rodada, como o fim do turno de um jogador ou a transição entre rodadas, depois que todos os jogadores concluíram suas ações.

Quando emitido no início do jogo ou no final de uma rodada, Event::Round geralmente torna desnecessária a emissão de outros eventos, pois essa situação naturalmente faz com que todas as entidades sejam atualizadas.

Fields

world: WorldId
round: Round