pub struct Infrastructure { /* private fields */ }Implementations
Sourceimpl Infrastructure
impl Infrastructure
Sourcepub fn builder() -> InfrastructureBuilder
pub fn builder() -> InfrastructureBuilder
Create an instance of Infrastructure using the builder syntax
Sourceimpl Infrastructure
impl Infrastructure
pub fn new() -> Self
pub const fn storage(&self, id: StorageId) -> &dyn Storage
pub const fn mine(&self, id: MineId) -> &dyn Mine
pub fn score(&self, stats: &InfrastructureStats) -> Result<Score>
Sourcepub fn round_base_production(
&self,
stats: &InfrastructureStats,
) -> Result<Resources>
pub fn round_base_production( &self, stats: &InfrastructureStats, ) -> Result<Resources>
Determines the amount of resources generated by the mines at their current level, before applying any modifiers, such as city stability.
Sourceimpl Infrastructure
impl Infrastructure
pub const fn academy(&self) -> &Academy
pub const fn farm(&self) -> &Farm
pub const fn iron_mine(&self) -> &IronMine
pub const fn prefecture(&self) -> &Prefecture
pub const fn quarry(&self) -> &Quarry
pub const fn sawmill(&self) -> &Sawmill
pub const fn silo(&self) -> &Silo
pub const fn stable(&self) -> &Stable
pub const fn wall(&self) -> &Wall
pub const fn warehouse(&self) -> &Warehouse
pub const fn workshop(&self) -> &Workshop
Sourcepub fn with_max_level() -> Self
pub fn with_max_level() -> Self
Creates a new instance with all buildings set to their maximum level.
pub const fn building(&self, id: BuildingId) -> &dyn Building
Sourcepub fn base_maintenance(
&self,
stats: &InfrastructureStats,
) -> Result<Maintenance>
pub fn base_maintenance( &self, stats: &InfrastructureStats, ) -> Result<Maintenance>
Determines the maintenance tax required for all buildings at their current levels.
Sourcepub fn has_required_levels(
&self,
requirements: &InfrastructureRequirements,
) -> bool
pub fn has_required_levels( &self, requirements: &InfrastructureRequirements, ) -> bool
Determines whether the infrastructure meets the requirements.