pub struct Military { /* private fields */ }Implementations
Sourceimpl Military
impl Military
pub fn collapse_armies(&mut self)
pub fn collapse_armies_in<K>(&mut self, key: K)where
K: ContinentKey,
Sourcepub fn intersection<K, I>(&self, keys: I) -> Result<Self>where
K: ContinentKey,
I: IntoIterator<Item = K>,
pub fn intersection<K, I>(&self, keys: I) -> Result<Self>where
K: ContinentKey,
I: IntoIterator<Item = K>,
Creates a new instance containing only entries related to a given set of coords.
pub fn army(&self, id: ArmyId) -> Result<&Army>
pub fn armies(&self) -> impl Iterator<Item = &Army>
pub fn count_armies(&self) -> usize
pub fn armies_at<K>(&self, key: K) -> &[Army]where
K: ContinentKey,
pub fn count_armies_at<K>(&self, key: K) -> usizewhere
K: ContinentKey,
pub fn idle_armies_at<K>(&self, key: K) -> impl Iterator<Item = &Army>where
K: ContinentKey,
pub fn armies_of<R>(&self, owner: R) -> impl Iterator<Item = &Army>
pub fn personnel(&self, id: ArmyId) -> Result<&ArmyPersonnel>
pub fn squads(&self, id: ArmyId) -> Result<Vec<Squad>>
pub fn fold_idle_personnel_at<K>(&self, key: K) -> ArmyPersonnelwhere
K: ContinentKey,
pub fn idle_squads_at<K>(&self, key: K) -> Vec<Squad>where
K: ContinentKey,
pub fn score_of<R>(&self, owner: R) -> Score
pub fn maintenance_of<R>(&self, owner: R) -> Maintenance
pub fn maneuver(&self, id: ManeuverId) -> Result<&Maneuver>
pub fn maneuvers(&self) -> impl Iterator<Item = &Maneuver>
Sourcepub fn maneuvers_at(&self, coord: Coord) -> impl Iterator<Item = &Maneuver>
pub fn maneuvers_at(&self, coord: Coord) -> impl Iterator<Item = &Maneuver>
Find all maneuvers whose origin or destination matches the specified coord.