Module influence
nil_
core
0.5.2
Module influence
Module Items
Structs
In nil_
core::
resources
nil_core
::
resources
Module
influence
Structs

Influence
Influence is a special resource which represents the political power of a ruler and is used to determine how many cities they can simultaneously control.