pub struct Resources {
pub food: Food,
pub iron: Iron,
pub stone: Stone,
pub wood: Wood,
}Fields
food: Foodiron: Ironstone: Stonewood: WoodImplementations
Sourceimpl Resources
impl Resources
Sourcepub fn builder() -> ResourcesBuilder
pub fn builder() -> ResourcesBuilder
Create an instance of Resources using the builder syntax
Sourceimpl Resources
impl Resources
pub fn new() -> Self
pub const fn splat(value: u32) -> Self
pub fn with_food(&self, food: Food) -> Self
pub fn with_iron(&self, iron: Iron) -> Self
pub fn with_stone(&self, stone: Stone) -> Self
pub fn with_wood(&self, wood: Wood) -> Self
pub fn silo(&self) -> Self
pub fn warehouse(&self) -> Self
pub fn add_within_capacity( &mut self, diff: &ResourcesDiff, capacity: &OverallStorageCapacity, )
Sourcepub fn checked_sub(&self, rhs: &Self) -> Option<Self>
pub fn checked_sub(&self, rhs: &Self) -> Option<Self>
Checked resource subtraction.
Returns None if there are not enough resources available.
pub fn sum(&self) -> u32
pub fn sum_silo(&self) -> u32
pub fn sum_warehouse(&self) -> u32
pub fn is_empty(&self) -> bool