pub enum RulerRef<'a> {
Bot(&'a Bot),
Player(&'a Player),
Precursor(&'a dyn Precursor),
}Variants
Implementations
Sourceimpl<'a> RulerRef<'a>
impl<'a> RulerRef<'a>
Sourcepub const fn is_player(&self) -> bool
pub const fn is_player(&self) -> bool
Returns true if the enum is RulerRef::Player otherwise false
Sourcepub const fn is_precursor(&self) -> bool
pub const fn is_precursor(&self) -> bool
Returns true if the enum is RulerRef::Precursor otherwise false
Sourceimpl<'a> RulerRef<'a>
impl<'a> RulerRef<'a>
Sourcepub fn try_unwrap_bot(self) -> Result<&'a Bot, TryUnwrapError<Self>>
pub fn try_unwrap_bot(self) -> Result<&'a Bot, TryUnwrapError<Self>>
Attempts to unwrap this value to the RulerRef::Bot variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_bot_ref(&self) -> Result<&&'a Bot, TryUnwrapError<&Self>>
pub fn try_unwrap_bot_ref(&self) -> Result<&&'a Bot, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the RulerRef::Bot variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_player(self) -> Result<&'a Player, TryUnwrapError<Self>>
pub fn try_unwrap_player(self) -> Result<&'a Player, TryUnwrapError<Self>>
Attempts to unwrap this value to the RulerRef::Player variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_player_ref(
&self,
) -> Result<&&'a Player, TryUnwrapError<&Self>>
pub fn try_unwrap_player_ref( &self, ) -> Result<&&'a Player, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the RulerRef::Player variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_precursor(
self,
) -> Result<&'a dyn Precursor, TryUnwrapError<Self>>
pub fn try_unwrap_precursor( self, ) -> Result<&'a dyn Precursor, TryUnwrapError<Self>>
Attempts to unwrap this value to the RulerRef::Precursor variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_precursor_ref(
&self,
) -> Result<&&'a dyn Precursor, TryUnwrapError<&Self>>
pub fn try_unwrap_precursor_ref( &self, ) -> Result<&&'a dyn Precursor, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the RulerRef::Precursor variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourceimpl<'a> RulerRef<'a>
impl<'a> RulerRef<'a>
Sourcepub fn unwrap_bot(self) -> &'a Bot
pub fn unwrap_bot(self) -> &'a Bot
Unwraps this value to the RulerRef::Bot variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_bot_ref(&self) -> &&'a Bot
pub fn unwrap_bot_ref(&self) -> &&'a Bot
Unwraps this reference to the RulerRef::Bot variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_player(self) -> &'a Player
pub fn unwrap_player(self) -> &'a Player
Unwraps this value to the RulerRef::Player variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_player_ref(&self) -> &&'a Player
pub fn unwrap_player_ref(&self) -> &&'a Player
Unwraps this reference to the RulerRef::Player variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_precursor(self) -> &'a dyn Precursor
pub fn unwrap_precursor(self) -> &'a dyn Precursor
Unwraps this value to the RulerRef::Precursor variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_precursor_ref(&self) -> &&'a dyn Precursor
pub fn unwrap_precursor_ref(&self) -> &&'a dyn Precursor
Unwraps this reference to the RulerRef::Precursor variant.
Panics if this value is of any other type.