pub enum RulerRefMut<'a> {
Bot(&'a mut Bot),
Player(&'a mut Player),
Precursor(&'a mut dyn Precursor),
}Variants
Implementations
Sourceimpl<'a> RulerRefMut<'a>
impl<'a> RulerRefMut<'a>
Sourcepub const fn is_bot(&self) -> bool
pub const fn is_bot(&self) -> bool
Returns true if the enum is RulerRefMut::Bot otherwise false
Sourcepub const fn is_player(&self) -> bool
pub const fn is_player(&self) -> bool
Returns true if the enum is RulerRefMut::Player otherwise false
Sourcepub const fn is_precursor(&self) -> bool
pub const fn is_precursor(&self) -> bool
Returns true if the enum is RulerRefMut::Precursor otherwise false
Sourceimpl<'a> RulerRefMut<'a>
impl<'a> RulerRefMut<'a>
Sourcepub fn try_unwrap_bot(self) -> Result<&'a mut Bot, TryUnwrapError<Self>>
pub fn try_unwrap_bot(self) -> Result<&'a mut Bot, TryUnwrapError<Self>>
Attempts to unwrap this value to the RulerRefMut::Bot variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_bot_ref(&self) -> Result<&&'a mut Bot, TryUnwrapError<&Self>>
pub fn try_unwrap_bot_ref(&self) -> Result<&&'a mut Bot, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the RulerRefMut::Bot variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_player(self) -> Result<&'a mut Player, TryUnwrapError<Self>>
pub fn try_unwrap_player(self) -> Result<&'a mut Player, TryUnwrapError<Self>>
Attempts to unwrap this value to the RulerRefMut::Player variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_player_ref(
&self,
) -> Result<&&'a mut Player, TryUnwrapError<&Self>>
pub fn try_unwrap_player_ref( &self, ) -> Result<&&'a mut Player, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the RulerRefMut::Player variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_precursor(
self,
) -> Result<&'a mut dyn Precursor, TryUnwrapError<Self>>
pub fn try_unwrap_precursor( self, ) -> Result<&'a mut dyn Precursor, TryUnwrapError<Self>>
Attempts to unwrap this value to the RulerRefMut::Precursor variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_precursor_ref(
&self,
) -> Result<&&'a mut dyn Precursor, TryUnwrapError<&Self>>
pub fn try_unwrap_precursor_ref( &self, ) -> Result<&&'a mut dyn Precursor, TryUnwrapError<&Self>>
Attempts to unwrap this reference to the RulerRefMut::Precursor variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourceimpl<'a> RulerRefMut<'a>
impl<'a> RulerRefMut<'a>
Sourcepub fn unwrap_bot(self) -> &'a mut Bot
pub fn unwrap_bot(self) -> &'a mut Bot
Unwraps this value to the RulerRefMut::Bot variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_bot_ref(&self) -> &&'a mut Bot
pub fn unwrap_bot_ref(&self) -> &&'a mut Bot
Unwraps this reference to the RulerRefMut::Bot variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_player(self) -> &'a mut Player
pub fn unwrap_player(self) -> &'a mut Player
Unwraps this value to the RulerRefMut::Player variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_player_ref(&self) -> &&'a mut Player
pub fn unwrap_player_ref(&self) -> &&'a mut Player
Unwraps this reference to the RulerRefMut::Player variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_precursor(self) -> &'a mut dyn Precursor
pub fn unwrap_precursor(self) -> &'a mut dyn Precursor
Unwraps this value to the RulerRefMut::Precursor variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_precursor_ref(&self) -> &&'a mut dyn Precursor
pub fn unwrap_precursor_ref(&self) -> &&'a mut dyn Precursor
Unwraps this reference to the RulerRefMut::Precursor variant.
Panics if this value is of any other type.
Sourceimpl<'a> RulerRefMut<'a>
impl<'a> RulerRefMut<'a>
pub fn resources_mut(&'a mut self) -> &'a mut Resources
pub fn take_resources(&mut self) -> Resources