Module build

Module build 

Structs

BuildBehavior
BuildBehaviorBuilder
Use builder syntax to set the inputs and finish with build().
BuildBuildingBehavior
BuildBuildingBehaviorBuilder
Use builder syntax to set the inputs and finish with build().
BuildStep