Module trade

Module trade 

Structs

BuyResourcesBehavior
BuyResourcesBehaviorBuilder
Use builder syntax to set the inputs and finish with build().
SellResourcesBehavior
SellResourcesBehaviorBuilder
Use builder syntax to set the inputs and finish with build().
TradeBehavior
TradeBehaviorBuilder
Use builder syntax to set the inputs and finish with build().