Modules
Structs
- City
- City
Builder - Use builder syntax to set the inputs and finish with
build(). - City
Name - City
Search - City
Search Builder - Use builder syntax to set the inputs and finish with
build(). - Public
City - Public data about a city, to which any player can have access.