pub enum Event {
ChatUpdated {
message: ChatMessage,
},
CityUpdated {
coord: Coord,
},
MilitaryUpdated {
player: PlayerId,
},
PlayerUpdated {
player: PlayerId,
},
PublicCityUpdated {
coord: Coord,
},
Report {
report: ReportId,
},
RoundUpdated {
round: Round,
},
}Variants
ChatUpdated
A new message has been sent in the chat.
Fields
message: ChatMessageCityUpdated
Indicates that there has been a change in the city’s data, be it public or not.
This event is only emitted to the city owner.
If you believe that all players should be notified,
consider using Event::PublicCityUpdated instead.
MilitaryUpdated
Indicates that the player’s military has changed. It usually means new maneuvers have been initiated, since the armies themselves are processed at the end of the round.
PlayerUpdated
Indicates that there has been a change in some of the player’s data, be it public or not.
PublicCityUpdated
Indicates that there has been a change in public data for the city.
As a rule, whenever the situation requires this event to be emitted,
Event::CityUpdated should also be emitted, but the opposite is not true!
Unlike Event::CityUpdated, which is emitted only to the city owner,
this event is sent to all players in the world.
Report
A report was generated.
RoundUpdated
Indicates changes in the round, such as the end of a player’s turn or the transition from one round to another, after all players have completed their actions.
When emitted at the start of the game or at the end of a round,
Event::RoundUpdated typically makes it unnecessary to emit other events,
as this situation naturally prompts all entities to update themselves.