pub trait Mine: Building {
// Required methods
fn mine_id(&self) -> MineId;
fn production(&self, stats: &MineStatsTable) -> Result<MineProduction>;
fn min_production(&self) -> MineProduction;
fn max_production(&self) -> MineProduction;
}Required Methods
fn mine_id(&self) -> MineId
Sourcefn production(&self, stats: &MineStatsTable) -> Result<MineProduction>
fn production(&self, stats: &MineStatsTable) -> Result<MineProduction>
Amount of resources generated by the mine at its current level.
Sourcefn min_production(&self) -> MineProduction
fn min_production(&self) -> MineProduction
Amount of resources generated by the mine at its minimum level.
Sourcefn max_production(&self) -> MineProduction
fn max_production(&self) -> MineProduction
Amount of resources generated by the mine at its maximum level.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".