Resources

Struct Resources 

pub struct Resources {
    pub food: Food,
    pub iron: Iron,
    pub stone: Stone,
    pub wood: Wood,
}

Fields

food: Foodiron: Ironstone: Stonewood: Wood

Implementations

Source

impl Resources

pub fn builder() -> ResourcesBuilder

Create an instance of Resources using the builder syntax

Source

impl Resources

pub const MIN: Self

Minimum possible amount of resources.

pub const MAX: Self

Maximum possible amount of resources.

pub const PLAYER: Self

Default amount of resources for a player.

pub const BOT: Self

Default amount of resources for a bot.

pub const PRECURSOR: Self

Default amount of resources for a precursor.

pub fn new() -> Self

pub const fn splat(value: u32) -> Self

pub fn with_food(&self, food: Food) -> Self

pub fn with_iron(&self, iron: Iron) -> Self

pub fn with_stone(&self, stone: Stone) -> Self

pub fn with_wood(&self, wood: Wood) -> Self

pub fn silo(&self) -> Self

pub fn warehouse(&self) -> Self

pub fn add_within_capacity( &mut self, diff: &ResourcesDiff, capacity: &OverallStorageCapacity, )

pub fn checked_sub(&self, rhs: &Self) -> Option<Self>

Checked resource subtraction. Returns None if there are not enough resources available.

pub fn sum(&self) -> u32

pub fn sum_silo(&self) -> u32

pub fn sum_warehouse(&self) -> u32

pub fn is_empty(&self) -> bool